@@ -493,7 +493,7 @@ typedef struct SMB_Status {
       unsigned short Error;
     } DosError;
     unsigned int NtStatus;
-  };
+  } status;
 } SMB_Status;
 
 typedef struct SMB_Tree_Structure * SMB_Tree_Handle;
@@ -582,3 +582,6 @@ extern SMB_State_Types SMBlib_State;
 extern int SMBlib_errno;
 extern int SMBlib_SMB_Error;          /* last Error             */
 #endif
+
+SMB_Tree_Handle SMB_TreeConnect(SMB_Handle_Type con, SMB_Tree_Handle tree,
+				char *path, char *password, char *dev);
